@@ -31,7 +31,7 @@ import re
 import urllib2
 import socket
 
-__version__ = '0.0.29'
+__version__ = '0.0.30'
 
 def write_report(error):
     filename = os.path.join(CACHE_PATH,'crash_report')
@@ -327,7 +327,17 @@ class KhweeteurWorker(QThread):
                     downloadProfileImage(status)
                     mlist.append((status.created_at_in_seconds,status))
                     if status.GetId() > twitter_last_id:
-                        twitter_last_id = status.GetId()
+                        twitter_last_id = status.GetId().value
+                for status in api.GetRetweetedOfMe(since_id=self.settings.value("twitter_last_id").toString()):
+                    downloadProfileImage(status)
+                    mlist.append((status.created_at_in_seconds,status))
+                    if status.GetId() > twitter_last_id:
+                        twitter_last_id = status.GetId()          
+                for status in api.GetRetweetedToMe(since_id=self.settings.value("twitter_last_id").toString()):
+                    downloadProfileImage(status)
+                    mlist.append((status.created_at_in_seconds,status))
+                    if status.GetId() > twitter_last_id:
+                        twitter_last_id = status.GetId()                          
                 for status in api.GetReplies(since_id=self.settings.value("twitter_last_id").toString()):
                     downloadProfileImage(status)
                     mlist.append((status.created_at_in_seconds,status))
